@@ -51,12 +51,12 @@ if __name__ == '__main__':
 
 
 
-	student1 = PND69('pepper')
+	student1 = Student('pepper')
 	print(student1.name)
 	student1.Hello()
 
 	print('----------')
-	student2 = PND69('tukta')
+	student2 = Student('tukta')
 	print(student2.name)
 	student2.Hello()
 
